define(['wq/app', './config', 'data/templates'],
function(app, config, templates) {

app.init(config, templates);

});
